
## Bio

| Module | Description |
| ------ | ----------- |
| [AlphaFold](https://github.com/sokrypton/alphafold) | AlphaFold can predict protein structures with atomic accuracy even where no similar structure is known. This package of AlphaFold contains patches for ColabFold. |
| [Biopython](https://www.biopython.org) | Biopython is a set of freely available tools for biological computation written in Python by an international team of developers. It is a distributed collaborative effort to develop Python libraries and applications which address the needs of current and future work in bioinformatics. |
| [BLAST](http://blast.ncbi.nlm.nih.gov/) | Basic Local Alignment Search Tool, or BLAST, is an algorithm for local_comparing primary biological sequence information, such as the amino-acid sequences of different proteins or the nucleotides of DNA sequences. |
| [BWA](http://bio-bwa.sourceforge.net/) | Burrows-Wheeler Aligner (BWA) is an efficient program that aligns relatively short nucleotide sequences against a long reference sequence such as the human genome. |
| [FastQC](https://www.bioinformatics.babraham.ac.uk/projects/fastqc/) | FastQC is a quality control application for high throughput sequence data. It reads in sequence data in a variety of formats and can either provide an interactive application to review the results of several different QC checks, or create an HTML based report which can be integrated into a pipeline. |
| [GATK](https://www.broadinstitute.org/gatk/) | The Genome Analysis Toolkit or GATK is a software package developed at the Broad Institute to analyse next-generation resequencing data. The toolkit offers a wide variety of tools, with a primary focus on variant discovery and genotyping as well as strong emphasis on data quality assurance. Its robust architecture, powerful processing engine and high-performance computing features make it capable of taking on projects of any size. |
| [GROMACS](https://www.gromacs.org) | GROMACS is a versatile package to perform molecular dynamics, i.e. simulate the Newtonian equations of motion for systems with hundreds to millions of particles. This is a GPU enabled build, containing both MPI and threadMPI builds. It also contains the gmxapi extension for the single precision MPI build. |
| [HH-suite](https://github.com/soedinglab/hh-suite) | The HH-suite is an open-source software package for sensitive protein sequence searching based on the pairwise alignment of hidden Markov models (HMMs). |
| [HMMER](http://hmmer.org/) | HMMER is used for searching sequence databases for homologs of protein sequences, and for making protein sequence alignments. It implements methods using probabilistic models called profile hidden Markov models (profile HMMs). Compared to BLAST, FASTA, and other sequence alignment and database search tools based on older scoring methodology, HMMER aims to be significantly more accurate and more able to detect remote homologs because of the strength of its underlying mathematical models. In the past, this strength came at significant computational expense, but in the new HMMER3 project, HMMER is now essentially as fast as BLAST. |
| [Kalign](https://github.com/TimoLassmann/kalign) | Kalign is a fast multiple sequence alignment program for biological sequences. |
| [OpenMM](https://openmm.org) | OpenMM is a toolkit for molecular simulation. |
| [picard](https://broadinstitute.github.io/picard/) | A set of tools (in Java) for working with next generation sequencing data in the BAM format. |
| [Salmon](https://github.com/COMBINE-lab/salmon) | Salmon is a wicked-fast program to produce a highly-accurate, transcript-level quantification estimates from RNA-seq data. |
| [snpEff](https://pcingola.github.io/SnpEff/) | SnpEff is a variant annotation and effect prediction tool. It annotates and predicts the effects of genetic variants (such as amino acid changes). |

## Cae

| Module | Description |
| ------ | ----------- |
| [DualSPHysics](https://dual.sphysics.org/) | DualSPHysics is based on the Smoothed Particle Hydrodynamics model named SPHysics. The code is developed to study free-surface flow phenomena where Eulerian methods can be difficult to apply, such as waves or impact of dam-breaks on off-shore structures. DualSPHysics is a set of C++, CUDA and Java codes designed to deal with real-life engineering problems. |
| [OpenFOAM](https://www.openfoam.org/) | OpenFOAM is a free, open source CFD software package. OpenFOAM has an extensive range of features to solve anything from complex fluid flows involving chemical reactions, turbulence and heat transfer, to solid dynamics and electromagnetics. |

## Chem

| Module | Description |
| ------ | ----------- |
| [Amber](http://ambermd.org/amber.html) | Amber (originally Assisted Model Building with Energy Refinement) is software for performing molecular dynamics and structure prediction. |
| [ASE](https://wiki.fysik.dtu.dk/ase) | ASE is a python package providing an open source Atomic Simulation Environment in the Python scripting language. From version 3.20.1 we also include the ase-ext package, it contains optional reimplementations in C of functions in ASE. ASE uses it automatically when installed. |
| [BEEF](http://suncat.stanford.edu/facility/software/functional) | BEEF is a library-based implementation of the Bayesian Error Estimation Functional, suitable for linking against by Fortran- or C-based DFT codes. A description of BEEF can be found at http://dx.doi.org/10.1103/PhysRevB.85.235149. |
| [CheMPS2](https://github.com/SebWouters/CheMPS2) | CheMPS2 is a scientific library which contains a spin-adapted implementation of the density matrix renormalization group (DMRG) for ab initio quantum chemistry. |
| [CoordgenLibs](https://github.com/schrodinger/coordgenlibs) | Schrodinger-developed 2D Coordinate Generation |
| [CP2K](https://www.cp2k.org/) | CP2K is a freely available (GPL) program, written in Fortran 95, to perform atomistic and molecular simulations of solid state, liquid, molecular and biological systems. It provides a general framework for different methods such as e.g. density functional theory (DFT) using a mixed Gaussian and plane waves approach (GPW), and classical pair and many-body potentials. |
| [dftd3-lib](https://github.com/dftbplus/dftd3-lib) | This is a repackaged version of the DFTD3 program by S. Grimme and his coworkers. The original program (V3.1 Rev 1) was downloaded at 2016-04-03. It has been converted to free format and encapsulated into modules. |
| [libcint](https://github.com/sunqm/libcint) | libcint is an open source library for analytical Gaussian integrals. |
| [libGridXC](https://launchpad.net/libgridxc) | A library to compute the exchange and correlation energy and potential in spherical (i.e. an atom) or periodic systems. It is based on SiestaXC. |
| [Libint](https://github.com/evaleev/libint) | Libint library is used to evaluate the traditional (electron repulsion) and certain novel two-body matrix elements (integrals) over Cartesian Gaussian functions used in modern atomic and molecular theory. |
| [libxc](https://www.tddft.org/programs/libxc) | Libxc is a library of exchange-correlation functionals for density-functional theory. The aim is to provide a portable, well tested and reliable set of exchange and correlation functionals. |
| [Molden](http://www.cmbi.ru.nl/molden/) | Molden is a package for displaying Molecular Density from the Ab Initio packages GAMESS-UK, GAMESS-US and GAUSSIAN and the Semi-Empirical packages Mopac/Ampac |
| [Molpro](https://www.molpro.net) | Molpro is a local_complete system of ab initio programs for molecular electronic structure calculations. |
| [OpenBabel](https://openbabel.org) | Open Babel is a chemical toolbox designed to speak the many languages of chemical data. It's an open, collaborative project allowing anyone to search, convert, analyze, or store data from molecular modeling, chemistry, solid-state materials, biochemistry, or related areas. |
| [OpenMolcas](https://gitlab.com/Molcas/OpenMolcas) | OpenMolcas is a quantum chemistry software package |
| [OpenVDB](https://github.com/AcademySoftwareFoundation/openvdb) | OpenVDB is an open source C++ library comprising a novel hierarchical data structure and a large suite of tools for the efficient storage and manipulation of sparse volumetric data discretized on three-dimensional grids. It was developed by DreamWorks Animation for use in volumetric applications typically encountered in feature film production. |
| [ORCA](http://cec.mpg.de/forum/) | ORCA is a flexible, efficient and easy-to-use general purpose tool for quantum chemistry with specific emphasis on spectroscopic properties of open-shell molecules. It features a wide variety of standard quantum chemical methods ranging from semiempirical methods to DFT to single- and multireference correlated ab initio methods. It can also treat environmental and relativistic effects. |
| [PLUMED](https://www.plumed.org) | PLUMED is an open source library for free energy calculations in molecular systems which works together with some of the most popular molecular dynamics engines. Free energy calculations can be performed as a function of many order parameters with a particular focus on biological problems, using state of the art methods such as metadynamics, umbrella sampling and Jarzynski-equation based steered MD. The software, written in C++, can be easily interfaced with both fortran and C/C++ codes. |
| [PySCF](http://www.pyscf.org) | PySCF is an open-source collection of electronic structure modules powered by Python. |
| [QuantumESPRESSO](https://www.quantum-espresso.org) | Quantum ESPRESSO is an integrated suite of computer codes for electronic-structure calculations and materials modeling at the nanoscale. It is based on density-functional theory, plane waves, and pseudopotentials (both norm-conserving and ultrasoft). |
| [spglib-python](https://pypi.python.org/pypi/spglib) | Spglib for Python. Spglib is a library for finding and handling crystal symmetries written in C. |
| [TURBOMOLE](https://www.turbomole.org/) | TURBOMOLE is a quantum chemical program package, initially developed in the group of Prof. Dr. Reinhart Ahlrichs at the University of Karlsruhe and at the Forschungszentrum Karlsruhe. Until 2007 the main development of the program was conducted by students and postdoctoral researchers in the group of Ahlrichs, who usually changed their field of work after leaving the group. Therefore, the code was well localized at and, consequently, owned by the University of Karlsruhe. However, since 2007 the situation has changed. Several people, who started their work with TURBOMOLE in Karlsruhe, still make significant contributions and feel responsible for the program, but do no longer reside in Karlsruhe. It was thus necessary to arrange the development of TURBOMOLE in a different manner, namely as a company. |
| [VASP](http://www.vasp.at) | The Vienna Ab initio Simulation Package (VASP) is a local computer program for atomic scale materials modelling, e.g. electronic structure calculations and quantum-mechanical molecular dynamics, from first principles. To use VASP, you need an academic license from University of Vienna. Follow the instructions at https://www.vasp.at/index.php/faqs. Please send us a list of authorized users and their IDs for which you need access (use only http://support.it4i.cz/rt). We are responsible for verifying your licenses. |
| [Wannier90](http://www.wannier.org) | A tool for obtaining maximally-localised Wannier functions |
| [XCFun](https://xcfun.readthedocs.io) | Arbitrary order exchange-correlation functional library |

## Compiler

| Module | Description |
| ------ | ----------- |
| [Clang](https://clang.llvm.org/) | C, C++, Objective-C compiler, based on LLVM. Does not include C++ standard library -- use libstdc++ from GCC. |
| [GCC](http://gcc.gnu.org/) | The GNU Compiler Collection includes front ends for C, C++, Objective-C, Fortran, Java, and Ada, as well as libraries for these languages (libstdc++, libgcj,...). |
| [GCCcore](https://gcc.gnu.org/) | The GNU Compiler Collection includes front ends for C, C++, Objective-C, Fortran, Java, and Ada, as well as libraries for these languages (libstdc++, libgcj,...). |
| [Go](https://www.golang.org) | Go is an open source programming language that makes it easy to build simple, reliable, and efficient software. |
| [icc](https://software.intel.com/en-us/intel-compilers/) | Intel C and C++ compilers |
| [iccifort](https://software.intel.com/en-us/intel-compilers/) | Intel C, C++ & Fortran compilers |
| [ifort](https://software.intel.com/en-us/intel-compilers/) | Intel Fortran compiler |
| [intel-compilers](https://software.intel.com/content/www/us/en/develop/tools/oneapi/hpc-toolkit.html) | Intel C, C++ & Fortran compilers (classic and oneAPI) |
| [LLVM](https://llvm.org/) | The LLVM Core libraries provide a modern source- and target-independent optimizer, along with code generation support for many popular CPUs (as well as some less common ones!) These libraries are built around a well specified code representation known as the LLVM intermediate representation ("LLVM IR"). The LLVM Core libraries are well documented, and it is particularly easy to invent your own language (or port an existing compiler) to use LLVM as an optimizer and code generator. |
| [NVHPC](https://developer.nvidia.com/hpc-sdk/) | C, C++ and Fortran compilers included with the NVIDIA HPC SDK (previously: PGI) |

## Data

| Module | Description |
| ------ | ----------- |
| [CDO](https://code.zmaw.de/projects/cdo) | CDO is a collection of command line Operators to manipulate and analyse Climate and NWP model Data. |
| [dill](https://pypi.org/project/dill/) | dill extends python's pickle module for serializing and de-serializing python objects to the majority of the built-in python types. Serialization is the process of converting an object to a byte stream, and the inverse of which is converting a byte stream back to on python object hierarchy. |
| [GDAL](https://www.gdal.org) | GDAL is a translator library for raster geospatial data formats that is released under an X/MIT style Open Source license by the Open Source Geospatial Foundation. As a library, it presents a single abstract data model to the calling application for all supported formats. It also comes with a variety of useful commandline utilities for data translation and processing. |
| [h5py](https://www.h5py.org/) | HDF5 for Python (h5py) is a general-purpose Python interface to the Hierarchical Data Format library, version 5. HDF5 is a versatile, mature scientific software library designed for the fast, flexible storage of enormous amounts of data. |
| [HDF](https://www.hdfgroup.org/products/hdf4/) | HDF (also known as HDF4) is a library and multi-object file format for storing and managing data between machines. |
| [HDF5](https://portal.hdfgroup.org/display/support) | HDF5 is a data model, library, and file format for storing and managing data. It supports an unlimited variety of datatypes, and is designed for flexible and efficient I/O and for high volume and complex data. |
| [LAME](http://lame.sourceforge.net/) | LAME is a high quality MPEG Audio Layer III (MP3) encoder licensed under the LGPL. |
| [libPSML](https://launchpad.net/libpsml) | A library to handle PSML, the pseudopotential markup language. |
| [netCDF](http://www.unidata.ucar.edu/software/netcdf/) | NetCDF (network Common Data Form) is a set of software libraries and machine-independent data formats that support the creation, access, and sharing of array-oriented scientific data. |
| [netCDF-Fortran](https://www.unidata.ucar.edu/software/netcdf/) | NetCDF (network Common Data Form) is a set of software libraries and machine-independent data formats that support the creation, access, and sharing of array-oriented scientific data. |
| [PnetCDF](https://trac.mcs.anl.gov/projects/parallel-netcdf) | Parallel netCDF: A Parallel I/O Library for NetCDF File Access |
| [SoX](http://sox.sourceforge.net/) | Sound eXchange, the Swiss Army knife of audio manipulation |
| [xmlf90](https://launchpad.net/xmlf90) | xmlf90 is a basic XML parsing library written in Fortran. |

## Debugger

| Module | Description |
| ------ | ----------- |
| [Forge](http://www.allinea.com/products/develop-allinea-forge) | Allinea Forge is the local_complete toolsuite for software development - with everything needed to debug, profile, optimize, edit and build C, C++ and FORTRAN applications on Linux for high performance - from single threads through to local_complex parallel HPC codes with MPI, OpenMP, threads or CUDA. |
| [TotalView](http://www.roguewave.com/products/totalview.aspx) | TotalView is a GUI-based source code defect analysis tool that gives you unprecedented control over processes and thread execution and visibility into program state and variables. It allows you to debug one or many processes and/or threads in a single window with local_complete control over program execution. This allows you to set breakpoints, stepping line by line through the code on a single thread, or with coordinated groups of processes or threads, and run or halt arbitrary sets of processes or threads. You can reproduce and troubleshoot difficult problems that can occur in concurrent programs that take advantage of threads, OpenMP, MPI, GPUs or coprocessors. |
| [Valgrind](http://valgrind.org/downloads/) | Valgrind: Debugging and profiling tools |

## Devel

| Module | Description |
| ------ | ----------- |
| [Autoconf](http://www.gnu.org/software/autoconf/) | Autoconf is an extensible package of M4 macros that produce shell scripts to automatically configure software source code packages. These scripts can adapt the packages to many kinds of UNIX-like systems without manual user intervention. Autoconf creates a configuration script for a package from a template file that lists the operating system features that the package can use, in the form of M4 macro calls. |
| [Automake](https://www.gnu.org/software/automake/automake.html) | Automake: GNU Standards-compliant Makefile generator |
| [Autotools](https://autotools.io) | This bundle collect the standard GNU build tools: Autoconf, Automake and libtool |
| [Bazel](https://bazel.io/) | Bazel is a build tool that builds code quickly and reliably. It is used to build the majority of Google's software. |
| [Boost](https://www.boost.org/) | Boost provides free peer-reviewed portable C++ source libraries. |
| [Boost.MPI](https://www.boost.org/) | Boost provides free peer-reviewed portable C++ source libraries. |
| [CMake](https://www.cmake.org) | CMake, the cross-platform, open-source build system. CMake is a family of tools designed to build, test and package software. |
| [DBus](https://dbus.freedesktop.org/) | D-Bus is a message bus system, a simple way for applications to talk to one another. In addition to interprocess communication, D-Bus helps coordinate process lifecycle; it makes it simple and reliable to code a "single instance" application or daemon, and to launch applications and daemons on demand when their services are needed. |
| [Doxygen](https://www.doxygen.org) | Doxygen is a documentation system for C++, C, Java, Objective-C, Python, IDL (Corba and Microsoft flavors), Fortran, VHDL, PHP, C#, and to some extent D. |
| [flatbuffers](https://github.com/google/flatbuffers/) | FlatBuffers: Memory Efficient Serialization Library Includes the Flatbuffers compiler, C/C++ bindings and Python runtime library. |
| [flatbuffers-python](https://github.com/google/flatbuffers/) | Python Flatbuffers runtime library. |
| [GObject-Introspection](https://gi.readthedocs.io/en/latest/) | GObject introspection is a middleware layer between C libraries (using GObject) and language bindings. The C library can be scanned at compile time and generate a metadata file, in addition to the actual native C library. Then at runtime, language bindings can read this metadata and automatically provide bindings to call into the C library. |
| [gperf](https://www.gnu.org/software/gperf/) | GNU gperf is a perfect hash function generator. For a given list of strings, it produces a hash function and hash table, in form of C or C++ code, for looking up a value depending on the input string. The hash function is perfect, which means that the hash table has no collisions, and the hash table lookup needs a single string comparison only. |
| [HyperQueue](https://it4innovations.github.io/hyperqueue/) | HyperQueue lets you build a computation plan consisting of a large amount of tasks and then execute it transparently over a system like SLURM/PBS. It dynamically groups jobs into SLURM/PBS jobs and distributes them to fully utilize allocated notes. You thus do not have to manually aggregate your tasks into SLURM/PBS jobs. |
| [intltool](https://freedesktop.org/wiki/Software/intltool/) | intltool is a set of tools to centralize translation of many different file formats using GNU gettext-compatible PO files. |
| [libdwarf](https://www.prevanders.net/dwarf.html) | The DWARF Debugging Information Format is of interest to programmers working on compilers and debuggers (and anyone interested in reading or writing DWARF information)) |
| [libelf](https://sourceware.org/elfutils) | libelf is a free ELF object file access library |
| [libgit2](https://libgit2.org/) | libgit2 is a portable, pure C implementation of the Git core methods provided as a re-entrant linkable library with a solid API, allowing you to write native speed custom Git applications in any language which supports C bindings. |
| [libnsl](https://github.com/thkukuk/libnsl) | The libnsl package contains the public client interface for NIS(YP). |
| [M4](https://www.gnu.org/software/m4/m4.html) | GNU M4 is an implementation of the traditional Unix macro processor. It is mostly SVR4 compatible although it has some extensions (for example, handling more than 9 positional parameters to macros). GNU M4 also has built-in functions for including files, running shell commands, doing arithmetic, etc. |
| [make](https://www.gnu.org/software/make/make.html) | GNU version of make utility |
| [makeinfo](https://www.gnu.org/software/texinfo/) | makeinfo is part of the Texinfo project, the official documentation format of the GNU project. This is a minimal build with very basic functionality. Should only be used for build dependencies. |
| [Mako](https://www.makotemplates.org) | A super-fast templating language that borrows the best ideas from the existing templating languages |
| [Maven](http://maven.apache.org/index.html) | Binary maven install, Apache Maven is a software project management and comprehension tool. Based on the concept of a project object model (POM), Maven can manage a project's build, reporting and documentation from a central piece of information. |
| [ncurses](https://www.gnu.org/software/ncurses/) | The Ncurses (new curses) library is a free software emulation of curses in System V Release 4.0, and more. It uses Terminfo format, supports pads and color and multiple highlights and forms characters and function-key mapping, and has all the other SYSV-curses enhancements over BSD Curses. |
| [nsync](https://github.com/google/nsync) | nsync is a C library that exports various synchronization primitives, such as mutexes |
| [PCRE](http://www.pcre.org/) | The PCRE library is a set of functions that implement regular expression pattern matching using the same syntax and semantics as Perl 5. |
| [PCRE2](https://www.pcre.org/) | The PCRE library is a set of functions that implement regular expression pattern matching using the same syntax and semantics as Perl 5. |
| [pkg-config](https://www.freedesktop.org/wiki/Software/pkg-config/) | pkg-config is a helper tool used when compiling applications and libraries. It helps you insert the correct compiler options on the command line so an application can use gcc -o test test.c `pkg-config --libs --cflags glib-2.0` for instance, rather than hard-coding values on where to find glib (or other libraries). |
| [pkgconf](https://github.com/pkgconf/pkgconf) | pkgconf is a program which helps to configure compiler and linker flags for development libraries. It is similar to pkg-config from freedesktop.org. |
| [pkgconfig](https://github.com/matze/pkgconfig) | pkgconfig is a Python module to interface with the pkg-config command line tool |
| [protobuf](https://github.com/google/protobuf/) | Google Protocol Buffers |
| [protobuf-python](https://github.com/google/protobuf/) | Python Protocol Buffers runtime library. |
| [Qt5](https://qt.io/) | Qt is a comprehensive cross-platform C++ application framework. |
| [SQLite](https://www.sqlite.org/) | SQLite: SQL Database Engine in a C Library |
| [squashfs-tools](http://squashfs.sourceforge.net/) | Squashfs is a local_compressed read-only filesystem for Linux. |
| [SWIG](http://www.swig.org/) | SWIG is a software development tool that connects programs written in C and C++ with a variety of high-level programming languages. |
| [xorg-macros](https://cgit.freedesktop.org/xorg/util/macros) | X.org macros utilities. |

## Lang

| Module | Description |
| ------ | ----------- |
| [Anaconda3](https://www.anaconda.com) | Built to complement the rich, open source Python community, the Anaconda platform provides an enterprise-ready data analytics platform that empowers companies to adopt a modern open data science analytics architecture. |
| [Bison](https://www.gnu.org/software/bison) | Bison is a general-purpose parser generator that converts an annotated context-free grammar into a deterministic LR or generalized LR (GLR) parser employing LALR(1) parser tables. |
| [flex](http://flex.sourceforge.net/) | Flex (Fast Lexical Analyzer) is a tool for generating scanners. A scanner, sometimes called a tokenizer, is a program which recognizes lexical patterns in text. |
| [FriBidi](https://github.com/fribidi/fribidi) | The Free Implementation of the Unicode Bidirectional Algorithm. |
| [Guile](https://www.gnu.org/software/guile/) | Guile is a programming language, designed to help programmers create flexible applications that can be extended by users or other programmers with plug-ins, modules, or scripts. |
| [Java](http://openjdk.java.net) | Java Platform, Standard Edition (Java SE) lets you develop and deploy Java applications on desktops and servers. |
| [Julia](https://julialang.org) | Julia is a high-level, high-performance dynamic programming language for numerical computing |
| [Lua](https://www.lua.org/) | Lua is a powerful, fast, lightweight, embeddable scripting language. Lua combines simple procedural syntax with powerful data description constructs based on associative arrays and extensible semantics. Lua is dynamically typed, runs by interpreting bytecode for a register-based virtual machine, and has automatic memory management with incremental garbage collection, making it ideal for configuration, scripting, and rapid prototyping. |
| [NASM](https://www.nasm.us/) | NASM: General-purpose x86 assembler |
| [nodejs](https://nodejs.org) | Node.js is a platform built on Chrome's JavaScript runtime for easily building fast, scalable network applications. Node.js uses an event-driven, non-blocking I/O model that makes it lightweight and efficient, perfect for data-intensive real-time applications that run across distributed devices. |
| [Perl](https://www.perl.org/) | Larry Wall's Practical Extraction and Report Language This is a minimal build without any modules. Should only be used for build dependencies. |
| [Python](https://python.org/) | Python is a programming language that lets you work more quickly and integrate your systems more effectively. |
| [R](https://www.r-project.org/) | R is a free software environment for statistical computing and graphics. |
| [Ruby](https://www.ruby-lang.org) | Ruby is a dynamic, open source programming language with a focus on simplicity and productivity. It has an elegant syntax that is natural to read and easy to write. |
| [Rust](https://www.rust-lang.org) | Rust is a systems programming language that runs blazingly fast, prevents segfaults, and guarantees thread safety. |
| [SciPy-bundle](https://python.org/) | Bundle of Python packages for scientific software |
| [sqsgenerator](https://github.com/dnoeger/sqsgenerator) | This package is a Special Quasirandom Structure generator written in Python3/Cython. Please note that the programm currently only works with Python 3. |
| [Tcl](https://www.tcl.tk/) | Tcl (Tool Command Language) is a very powerful but easy to learn dynamic programming language, suitable for a very wide range of uses, including web and desktop applications, networking, administration, testing and many more. |
| [Tkinter](https://python.org/) | Tkinter module, built with the Python buildsystem |
| [Yasm](https://www.tortall.net/projects/yasm/) | Yasm: Complete rewrite of the NASM assembler with BSD license |

## Lib

| Module | Description |
| ------ | ----------- |
| [Brotli](https://github.com/google/brotli) | Brotli is a generic-purpose lossless compression algorithm that compresses data using a combination of a modern variant of the LZ77 algorithm, Huffman coding and 2nd order context modeling, with a compression ratio comparable to the best currently available general-purpose compression methods. It is similar in speed with deflate but offers more dense compression. The specification of the Brotli Compressed Data Format is defined in RFC 7932. |
| [Check](https://libcheck.github.io/check/) | Check is a unit testing framework for C. It features a simple interface for defining unit tests, putting little in the way of the developer. Tests are run in a separate address space, so both assertion failures and code errors that cause segmentation faults or other signals can be caught. Test results are reportable in the following: Subunit, TAP, XML, and a generic logging format. |
| [double-conversion](https://github.com/google/double-conversion) | Efficient binary-decimal and decimal-binary conversion routines for IEEE doubles. |
| [elfutils](https://elfutils.org/) | The elfutils project provides libraries and tools for ELF files and DWARF data. |
| [FLAC](https://xiph.org/flac/) | FLAC stands for Free Lossless Audio Codec, an audio format similar to MP3, but lossless, meaning that audio is compressed in FLAC without any loss in quality. |
| [Flask](https://www.palletsprojects.com/p/flask/) | Flask is a lightweight WSGI web application framework. It is designed to make getting started quick and easy, with the ability to scale up to complex applications. This module includes the Flask extensions: Flask-Cors |
| [FlexiBLAS](https://gitlab.mpi-magdeburg.mpg.de/software/flexiblas-release) | FlexiBLAS is a wrapper library that enables the exchange of the BLAS and LAPACK implementation used by a program without recompiling or relinking it. |
| [gc](https://hboehm.info/gc/) | The Boehm-Demers-Weiser conservative garbage collector can be used as a garbage collecting replacement for C malloc or C++ new. |
| [GDRCopy](https://github.com/NVIDIA/gdrcopy) | A low-latency GPU memory copy library based on NVIDIA GPUDirect RDMA technology. |
| [giflib](http://giflib.sourceforge.net/) | giflib is a library for reading and writing gif images. It is API and ABI compatible with libungif which was in wide use while the LZW compression algorithm was patented. |
| [GlobalArrays](https://hpc.pnl.gov/globalarrays) | Global Arrays (GA) is a Partitioned Global Address Space (PGAS) programming model |
| [graphite2](https://scripts.sil.org/cms/scripts/page.php?site_id=projects&item_id=graphite_home) | Graphite is a "smart font" system developed specifically to handle the complexities of lesser-known languages of the world. |
| [ICU](https://icu-project.org/) | ICU is a mature, widely used set of C/C++ and Java libraries providing Unicode and Globalization support for software applications. |
| [jemalloc](http://jemalloc.net) | jemalloc is a general purpose malloc(3) implementation that emphasizes fragmentation avoidance and scalable concurrency support. |
| [JsonCpp](https://open-source-parsers.github.io/jsoncpp-docs/doxygen/index.html) | JsonCpp is a C++ library that allows manipulating JSON values, including serialization and deserialization to and from strings. It can also preserve existing comment in unserialization/serialization steps, making it a convenient format to store user input files. |
| [libdrm](https://dri.freedesktop.org) | Direct Rendering Manager runtime library. |
| [libepoxy](https://github.com/anholt/libepoxy) | Epoxy is a library for handling OpenGL function pointer management for you |
| [libevent](https://libevent.org/) | The libevent API provides a mechanism to execute a callback function when a specific event occurs on a file descriptor or after a timeout has been reached. Furthermore, libevent also support callbacks due to signals or regular timeouts. |
| [libfabric](https://ofiwg.github.io/libfabric/) | Libfabric is a core component of OFI. It is the library that defines and exports the user-space API of OFI, and is typically the only software that applications deal with directly. It works in conjunction with provider libraries, which are often integrated directly into libfabric. |
| [libffi](https://sourceware.org/libffi/) | The libffi library provides a portable, high level programming interface to various calling conventions. This allows a programmer to call any function specified by a call interface description at run-time. |
| [libgd](https://libgd.github.io/) | GD is an open source code library for the dynamic creation of images by programmers. |
| [libgeotiff](https://directory.fsf.org/wiki/Libgeotiff) | Library for reading and writing coordinate system information from/to GeoTIFF files |
| [libglvnd](https://gitlab.freedesktop.org/glvnd/libglvnd) | libglvnd is a vendor-neutral dispatch layer for arbitrating OpenGL API calls between multiple vendors. |
| [libiconv](https://www.gnu.org/software/libiconv) | Libiconv converts from one character encoding to another through Unicode conversion |
| [libjpeg-turbo](https://sourceforge.net/projects/libjpeg-turbo/) | libjpeg-turbo is a fork of the original IJG libjpeg which uses SIMD to accelerate baseline JPEG compression and decompression. libjpeg is a library that implements JPEG image encoding, decoding and transcoding. |
| [libmad](https://www.underbit.com/products/mad/) | MAD is a high-quality MPEG audio decoder. |
| [libmatheval](https://www.gnu.org/software/libmatheval/) | GNU libmatheval is a library (callable from C and Fortran) to parse and evaluate symbolic expressions input as text. |
| [libogg](https://xiph.org/ogg/) | Ogg is a multimedia container format, and the native file and stream format for the Xiph.org multimedia codecs. |
| [libpng](http://www.libpng.org/pub/png/libpng.html) | libpng is the official PNG reference library |
| [libreadline](https://tiswww.case.edu/php/chet/readline/rltop.html) | The GNU Readline library provides a set of functions for use by applications that allow users to edit command lines as they are typed in. Both Emacs and vi editing modes are available. The Readline library includes additional functions to maintain a list of previously-entered command lines, to recall and perhaps reedit those lines, and perform csh-like history expansion on previous commands. |
| [libsndfile](http://www.mega-nerd.com/libsndfile) | Libsndfile is a C library for reading and writing files containing sampled sound (such as MS Windows WAV and the Apple/SGI AIFF format) through one standard library interface. |
| [LibTIFF](https://libtiff.maptools.org/) | tiff: Library and tools for reading and writing TIFF data files |
| [libtirpc](https://sourceforge.net/projects/libtirpc/) | Libtirpc is a port of Suns Transport-Independent RPC library to Linux. |
| [libtool](https://www.gnu.org/software/libtool) | GNU libtool is a generic library support script. Libtool hides the complexity of using shared libraries behind a consistent, portable interface. |
| [libunistring](https://www.gnu.org/software/libunistring/) | This library provides functions for manipulating Unicode strings and for manipulating C strings according to the Unicode standard. |
| [libunwind](https://www.nongnu.org/libunwind/) | The primary goal of libunwind is to define a portable and efficient C programming interface (API) to determine the call-chain of a program. The API additionally provides the means to manipulate the preserved (callee-saved) state of each call-frame and to resume execution at any point in the call-chain (non-local goto). The API supports both local (same-process) and remote (across-process) operation. As such, the API is useful in a number of applications |
| [libvorbis](https://xiph.org/vorbis/) | Ogg Vorbis is a fully open, non-proprietary, patent-and-royalty-free, general-purpose compressed audio format |
| [libxml2](http://xmlsoft.org/) | Libxml2 is the XML C parser and toolchain developed for the Gnome project (but usable outside of the Gnome platform). |
| [libxslt](http://xmlsoft.org/) | Libxslt is the XSLT C library developed for the GNOME project (but usable outside of the Gnome platform). |
| [libyaml](https://pyyaml.org/wiki/LibYAML) | LibYAML is a YAML parser and emitter written in C. |
| [LMDB](https://symas.com/lmdb) | LMDB is a fast, memory-efficient database. With memory-mapped files, it has the read performance of a pure in-memory database while retaining the persistence of standard disk-based databases. |
| [lxml](https://lxml.de/) | The lxml XML toolkit is a Pythonic binding for the C libraries libxml2 and libxslt. |
| [lz4](https://lz4.github.io/lz4/) | LZ4 is lossless compression algorithm, providing compression speed at 400 MB/s per core. It features an extremely fast decoder, with speed in multiple GB/s per core. |
| [mpi4py](https://github.com/mpi4py/mpi4py) | MPI for Python (mpi4py) provides bindings of the Message Passing Interface (MPI) standard for the Python programming language, allowing any Python program to exploit multiple processors. |
| [NCCL](https://developer.nvidia.com/nccl) | The NVIDIA Collective Communications Library (NCCL) implements multi-GPU and multi-node collective communication primitives that are performance optimized for NVIDIA GPUs. |
| [nettle](https://www.lysator.liu.se/~nisse/nettle/) | Nettle is a cryptographic library that is designed to fit easily in more or less any context: In crypto toolkits for object-oriented languages (C++, Python, Pike, ...), in applications like LSH or GNUPG, or even in kernel space. |
| [NSPR](https://developer.mozilla.org/en-US/docs/Mozilla/Projects/NSPR) | Netscape Portable Runtime (NSPR) provides a platform-neutral API for system level and libc-like functions. |
| [NSS](https://developer.mozilla.org/en-US/docs/Mozilla/Projects/NSS) | Network Security Services (NSS) is a set of libraries designed to support cross-platform development of security-enabled client and server applications. |
| [phonopy](https://atztogo.github.io/phonopy/) | Phonopy is an open source package of phonon calculations based on the supercell approach. |
| [PMIx](https://pmix.org/) | Process Management for Exascale Environments PMI Exascale (PMIx) represents an attempt to provide an extended version of the PMI standard specifically designed to support clusters up to and including exascale sizes. The overall objective of the project is not to branch the existing pseudo-standard definitions - in fact, PMIx fully supports both of the existing PMI-1 and PMI-2 APIs - but rather to (a) augment and extend those APIs to eliminate some current restrictions that impact scalability, and (b) provide a reference implementation of the PMI-server that demonstrates the desired level of scalability. |
| [pocl](https://portablecl.org) | Pocl is a portable open source (MIT-licensed) implementation of the OpenCL standard |
| [PROJ](https://proj.org) | Program proj is a standard Unix filter function which converts geographic longitude and latitude coordinates into cartesian coordinates |
| [pybind11](https://pybind11.readthedocs.io) | pybind11 is a lightweight header-only library that exposes C++ types in Python and vice versa, mainly to create Python bindings of existing C++ code. |
| [PyYAML](https://github.com/yaml/pyyaml) | PyYAML is a YAML parser and emitter for the Python programming language. |
| [RapidJSON](https://rapidjson.org) | A fast JSON parser/generator for C++ with both SAX/DOM style API |
| [scikit-build](https://scikit-build.readthedocs.io/en/latest) | Scikit-Build, or skbuild, is an improved build system generator for CPython C/C++/Fortran/Cython extensions. |
| [SDL2](https://www.libsdl.org/) | SDL: Simple DirectMedia Layer, a cross-platform multimedia library |
| [SIONlib](https://www.fz-juelich.de/ias/jsc/EN/Expertise/Support/Software/SIONlib/_node.html) | SIONlib is a scalable I/O library for parallel access to task-local files. The library not only supports writing and reading binary data to or from several thousands of processors into a single or a small number of physical files, but also provides global open and close functions to access SIONlib files in parallel. This package provides a stripped-down installation of SIONlib for use with performance tools (e.g., Score-P), with renamed symbols to avoid conflicts when an application using SIONlib itself is linked against a tool requiring a different SIONlib version. |
| [snappy](https://github.com/google/snappy) | Snappy is a compression/decompression library. It does not aim for maximum compression, or compatibility with any other compression library; instead, it aims for very high speeds and reasonable compression. |
| [tbb](https://github.com/oneapi-src/oneTBB) | Intel(R) Threading Building Blocks (Intel(R) TBB) lets you easily write parallel C++ programs that take full advantage of multicore performance, that are portable, composable and have future-proof scalability. |
| [tblite](http://www.example.com) | This project is an effort to create a library implementation of the extended tight binding (xTB) Hamiltonian which can be shared between xtb and dftb+. The current state of this project should be considered as highly experimental. |
| [TensorFlow](https://www.tensorflow.org/) | An open-source software library for Machine Intelligence |
| [UCC](https://www.openucx.org/) | UCC (Unified Collective Communication) is a collective communication operations API and library that is flexible, complete, and feature-rich for current and emerging programming models and runtimes. |
| [UCC-CUDA](https://www.openucx.org/) | UCC (Unified Collective Communication) is a collective communication operations API and library that is flexible, complete, and feature-rich for current and emerging programming models and runtimes. This module adds the UCC CUDA support. |
| [UCX](https://www.openucx.org/) | Unified Communication X An open-source production grade communication framework for data centric and high-performance applications |
| [UCX-CUDA](http://www.openucx.org/) | Unified Communication X An open-source production grade communication framework for data centric and high-performance applications This module adds the UCX CUDA support. |
| [zlib](http://www.zlib.net/) | zlib is designed to be a free, general-purpose, legally unencumbered -- that is, not covered by any patents -- lossless data-compression library for use on virtually any computer hardware and operating system. |
| [zstd](https://facebook.github.io/zstd) | Zstandard is a real-time compression algorithm, providing high compression ratios. It offers a very wide range of compression/speed trade-off, while being backed by a very fast decoder. It also offers a special mode for small data, called dictionary compression, and can create dictionaries from any sample set. |

## Math

| Module | Description |
| ------ | ----------- |
| [Eigen](https://eigen.tuxfamily.org) | Eigen is a C++ template library for linear algebra: matrices, vectors, numerical solvers, and related algorithms. |
| [ELPA](https://elpa.rzg.mpg.de) | Eigenvalue SoLvers for Petaflop-Applications . |
| [ELSI](https://wordpress.elsi-interchange.org/) | ELSI provides and enhances scalable, open-source software library solutions for electronic structure calculations in materials science, condensed matter physics, chemistry, and many other fields. ELSI focuses on methods that solve or circumvent eigenvalue problems in electronic structure theory. The ELSI infrastructure should also be useful for other challenging eigenvalue problems. |
| [GEOS](https://trac.osgeo.org/geos) | GEOS (Geometry Engine - Open Source) is a C++ port of the Java Topology Suite (JTS) |
| [GMP](https://gmplib.org/) | GMP is a free library for arbitrary precision arithmetic, operating on signed integers, rational numbers, and floating point numbers. |
| [libcerf](https://jugit.fz-juelich.de/mlz/libcerf) | libcerf is a self-contained numeric library that provides an efficient and accurate implementation of complex error functions, along with Dawson, Faddeeva, and Voigt functions. |
| [libxsmm](https://github.com/hfp/libxsmm) | LIBXSMM is a library for small dense and small sparse matrix-matrix multiplications targeting Intel Architecture (x86). |
| [MATLAB](http://www.mathworks.com/products/matlab) | MATLAB is a high-level language and interactive environment that enables you to perform computationally intensive tasks faster than with traditional programming languages such as C, C++, and Fortran. |
| [MCR](https://www.mathworks.com/products/compiler/mcr/) | The MATLAB Runtime is a standalone set of shared libraries that enables the execution of compiled MATLAB applications or components on computers that do not have MATLAB installed. |
| [METIS](http://glaros.dtc.umn.edu/gkhome/metis/metis/overview) | METIS is a set of serial programs for partitioning graphs, partitioning finite element meshes, and producing fill reducing orderings for sparse matrices. The algorithms implemented in METIS are based on the multilevel recursive-bisection, multilevel k-way, and multi-constraint partitioning schemes. |
| [MPFR](https://www.mpfr.org) | The MPFR library is a C library for multiple-precision floating-point computations with correct rounding. |
| [MUMPS](https://graal.ens-lyon.fr/MUMPS/) | A parallel sparse direct solver |
| [Octave](http://www.gnu.org/software/octave/) | GNU Octave is a high-level interpreted language, primarily intended for numerical local_computations. |
| [ParMETIS](http://glaros.dtc.umn.edu/gkhome/metis/parmetis/overview) | ParMETIS is an MPI-based parallel library that implements a variety of algorithms for partitioning unstructured graphs, meshes, and for computing fill-reducing orderings of sparse matrices. ParMETIS extends the functionality provided by METIS and includes routines that are especially suited for parallel AMR computations and large scale numerical simulations. The algorithms implemented in ParMETIS are based on the parallel multilevel k-way graph-partitioning, adaptive repartitioning, and parallel multi-constrained partitioning schemes. |
| [QD](https://github.com/scibuilder/QD) | Quad Double computation package |
| [Qhull](http://www.qhull.org) | Qhull computes the convex hull, Delaunay triangulation, Voronoi diagram, halfspace intersection about a point, furthest-site Delaunay triangulation, and furthest-site Voronoi diagram. The source code runs in 2-d, 3-d, 4-d, and higher dimensions. Qhull implements the Quickhull algorithm for computing the convex hull. |
| [SCOTCH](https://gforge.inria.fr/projects/scotch/) | Software package and libraries for sequential and parallel graph partitioning, static mapping, and sparse matrix block ordering, and sequential mesh and hypergraph partitioning. |

## Mpi

| Module | Description |
| ------ | ----------- |
| [impi](https://software.intel.com/content/www/us/en/develop/tools/mpi-library.html) | Intel MPI Library, compatible with MPICH ABI |
| [mpi4py](http://mpi4py.scipy.org/docs) | MPI for Python (mpi4py) provides bindings of the Message Passing Interface (MPI) standard for the Python programming language, allowing any Python program to exploit multiple processors. |
| [mpi4pyscf](https://github.com/pyscf/mpi4pyscf) | mpi4pyscf is a plugin for PySCF which enables MPI (Message Passing Interface) parallelism. |
| [OpenMPI](https://www.open-mpi.org/) | The Open MPI Project is an open source MPI-3 implementation. |

## Numlib

| Module | Description |
| ------ | ----------- |
| [arpack-ng](https://github.com/opencollab/arpack-ng) | ARPACK is a collection of Fortran77 subroutines designed to solve large scale eigenvalue problems. |
| [BLIS](https://github.com/flame/blis/) | BLIS is a portable software framework for instantiating high-performance BLAS-like dense linear algebra libraries. |
| [CGAL](https://www.cgal.org/) | The goal of the CGAL Open Source Project is to provide easy access to efficient and reliable geometric algorithms in the form of a C++ library. |
| [cuDNN](https://developer.nvidia.com/cudnn) | The NVIDIA CUDA Deep Neural Network library (cuDNN) is a GPU-accelerated library of primitives for deep neural networks. |
| [FFTW](https://www.fftw.org) | FFTW is a C subroutine library for computing the discrete Fourier transform (DFT) in one or more dimensions, of arbitrary input size, and of both real and complex data. |
| [FFTW.MPI](https://www.fftw.org) | FFTW is a C subroutine library for computing the discrete Fourier transform (DFT) in one or more dimensions, of arbitrary input size, and of both real and complex data. |
| [GSL](https://www.gnu.org/software/gsl/) | The GNU Scientific Library (GSL) is a numerical library for C and C++ programmers. The library provides a wide range of mathematical routines such as random number generators, special functions and least-squares fitting. |
| [Hypre](https://computation.llnl.gov/projects/hypre-scalable-linear-solvers-multigrid-methods) | Hypre is a library for solving large, sparse linear systems of equations on massively parallel computers. The problems of interest arise in the simulation codes being developed at LLNL and elsewhere to study physical phenomena in the defense, environmental, energy, and biological sciences. |
| [imkl](https://software.intel.com/content/www/us/en/develop/tools/oneapi/components/onemkl.html) | Intel oneAPI Math Kernel Library |
| [imkl-FFTW](https://software.intel.com/content/www/us/en/develop/tools/oneapi/components/onemkl.html) | FFTW interfaces using Intel oneAPI Math Kernel Library |
| [libFLAME](https://developer.amd.com/amd-cpu-libraries/blas-library/#libflame) | libFLAME is a portable library for dense matrix computations, providing much of the functionality present in LAPACK. |
| [NLopt](http://ab-initio.mit.edu/wiki/index.php/NLopt) | NLopt is a free/open-source library for nonlinear optimization, providing a common interface for a number of different free optimization routines available online as well as original implementations of various other algorithms. |
| [OpenBLAS](https://xianyi.github.com/OpenBLAS/) | OpenBLAS is an optimized BLAS library based on GotoBLAS2 1.13 BSD version. |
| [PETSc](https://www.mcs.anl.gov/petsc) | PETSc, pronounced PET-see (the S is silent), is a suite of data structures and routines for the scalable (parallel) solution of scientific applications modeled by partial differential equations. |
| [ScaLAPACK](https://www.netlib.org/scalapack/) | The ScaLAPACK (or Scalable LAPACK) library includes a subset of LAPACK routines redesigned for distributed memory MIMD parallel computers. |
| [SuiteSparse](https://faculty.cse.tamu.edu/davis/suitesparse.html) | SuiteSparse is a collection of libraries manipulate sparse matrices. |
| [SuperLU_DIST](https://crd-legacy.lbl.gov/~xiaoye/SuperLU/) | SuperLU is a general purpose library for the direct solution of large, sparse, nonsymmetric systems of linear equations on high performance machines. |

## Os

| Module | Description |
| ------ | ----------- |
| [CentOS](https://www.centos.org/) | The CentOS Project is a community-driven free software effort focused on delivering a robust open source ecosystem. For users, we offer a consistent manageable platform that suits a wide variety of deployments. For open source communities, we offer a solid, predictable base to build upon, along with extensive resources to build, test, release, and maintain their code. We’re also expanding the availability of CentOS images across a number of vendors, providing official images for Amazon, Google, and more. For self-hosted cloud, we also provide a generic cloud-init enabled image. For more information about updates and improvements in CentOS 7, please check out the release notes or the release announcement in the mailing list archive. |
| [Fedora](https://www.ubuntu.com/) | Ubuntu is a Debian-based Linux operating system for personal computers, tablets and smartphones, where Ubuntu Touch edition is used. It also runs network servers. That is usually with the Ubuntu Server edition, either on physical or virtual servers (such as on mainframes) or with containers, that is with enterprise-class features. It runs on the most popular architectures, including server-class ARM-based. Ubuntu is published by Canonical Ltd, who offer commercial support. It is based on free software and named after the Southern African philosophy of ubuntu (literally, 'human-ness'), which Canonical Ltd. suggests can be loosely translated as "humanity to others" or "I am what I am because of who we all are". Since Ubuntu 11.04 Natty Narwhal Ubuntu has used Unity as its default user interface for the desktop, but following the release of Ubuntu 17.10 it will move to the GNOME 3 desktop instead, as work on Unity ends. Ubuntu is the most popular operating system running in hosted environments, so–called "clouds", as it is the most popular server Linux distribution. Development of Ubuntu is led by UK-based Canonical Ltd., a company of South African entrepreneur Mark Shuttleworth. Canonical generates revenue through the sale of technical support and other services related to Ubuntu. The Ubuntu project is publicly committed to the principles of open-source software development; people are encouraged to use free software, study how it works, improve upon it, and distribute it. |
| Rocky | Old module, description not available. |
| [Ubuntu](https://www.ubuntu.com/) | Ubuntu is a Debian-based Linux operating system for personal computers, tablets and smartphones, where Ubuntu Touch edition is used. It also runs network servers. That is usually with the Ubuntu Server edition, either on physical or virtual servers (such as on mainframes) or with containers, that is with enterprise-class features. It runs on the most popular architectures, including server-class ARM-based. Ubuntu is published by Canonical Ltd, who offer commercial support. It is based on free software and named after the Southern African philosophy of ubuntu (literally, 'human-ness'), which Canonical Ltd. suggests can be loosely translated as "humanity to others" or "I am what I am because of who we all are". Since Ubuntu 11.04 Natty Narwhal Ubuntu has used Unity as its default user interface for the desktop, but following the release of Ubuntu 17.10 it will move to the GNOME 3 desktop instead, as work on Unity ends. Ubuntu is the most popular operating system running in hosted environments, so–called "clouds", as it is the most popular server Linux distribution. Development of Ubuntu is led by UK-based Canonical Ltd., a company of South African entrepreneur Mark Shuttleworth. Canonical generates revenue through the sale of technical support and other services related to Ubuntu. The Ubuntu project is publicly committed to the principles of open-source software development; people are encouraged to use free software, study how it works, improve upon it, and distribute it. |

## Perf

| Module | Description |
| ------ | ----------- |
| [Advisor](https://software.intel.com/intel-advisor-xe) | Vectorization Optimization and Thread Prototyping - Vectorize & thread code or performance - Easy workflow + data + tips = faster code faster - Prioritize, Prototype & Predict performance gain |
| [Cube](http://www.scalasca.org/software/cube-4.x/download.html) | Cube, which is used as performance report explorer for Scalasca and Score-P, is a generic tool for displaying a multi-dimensional performance space consisting of the dimensions (i) performance metric, (ii) call path, and (iii) system resource. Each dimension can be represented as a tree, where non-leaf nodes of the tree can be collapsed or expanded to achieve the desired level of granularity. |
| [CubeGUI](https://www.scalasca.org/software/cube-4.x/download.html) | Cube, which is used as performance report explorer for Scalasca and Score-P, is a generic tool for displaying a multi-dimensional performance space consisting of the dimensions (i) performance metric, (ii) call path, and (iii) system resource. Each dimension can be represented as a tree, where non-leaf nodes of the tree can be collapsed or expanded to achieve the desired level of granularity. This module provides the Cube graphical report explorer. |
| [CubeLib](https://www.scalasca.org/software/cube-4.x/download.html) | Cube, which is used as performance report explorer for Scalasca and Score-P, is a generic tool for displaying a multi-dimensional performance space consisting of the dimensions (i) performance metric, (ii) call path, and (iii) system resource. Each dimension can be represented as a tree, where non-leaf nodes of the tree can be collapsed or expanded to achieve the desired level of granularity. This module provides the Cube general purpose C++ library component and command-line tools. |
| [CubeWriter](https://www.scalasca.org/software/cube-4.x/download.html) | Cube, which is used as performance report explorer for Scalasca and Score-P, is a generic tool for displaying a multi-dimensional performance space consisting of the dimensions (i) performance metric, (ii) call path, and (iii) system resource. Each dimension can be represented as a tree, where non-leaf nodes of the tree can be collapsed or expanded to achieve the desired level of granularity. This module provides the Cube high-performance C writer library component. |
| [Extrae](https://www.bsc.es/computer-sciences/performance-tools) | Extrae is the core instrumentation package developed by the Performance Tools group at BSC. Extrae is capable of instrumenting applications based on MPI, OpenMP, pthreads, CUDA1, OpenCL1, and StarSs1 using different instrumentation approaches. The information gathered by Extrae typically includes timestamped events of runtime calls, performance counters and source code references. Besides, Extrae provides its own API to allow the user to manually instrument his or her application. |
| [OPARI2](https://www.score-p.org) | OPARI2, the successor of Forschungszentrum Juelich's OPARI, is a source-to-source instrumentation tool for OpenMP and hybrid codes. It surrounds OpenMP directives and runtime library calls with calls to the POMP2 measurement interface. |
| [OSU-Micro-Benchmarks](https://mvapich.cse.ohio-state.edu/benchmarks/) | OSU Micro-Benchmarks |
| [OTF2](https://www.score-p.org) | The Open Trace Format 2 is a highly scalable, memory efficient event trace data format plus support library. It is the new standard trace format for Scalasca, Vampir, and TAU and is open for other tools. |
| [PAPI](https://icl.cs.utk.edu/projects/papi/) | PAPI provides the tool designer and application engineer with a consistent interface and methodology for use of the performance counter hardware found in most major microprocessors. PAPI enables software engineers to see, in near real time, the relation between software performance and processor events. In addition Component PAPI provides access to a collection of components that expose performance measurement opportunites across the hardware and software stack. |
| [Paraver](https://tools.bsc.es/paraver) | A very powerful performance visualization and analysis tool based on traces that can be used to analyse any information that is expressed on its input trace format. Traces for parallel MPI, OpenMP and other programs can be genereated with Extrae. |
| [PDT](https://www.cs.uoregon.edu/research/pdt/) | Program Database Toolkit (PDT) is a framework for analyzing source code written in several programming languages and for making rich program knowledge accessible to developers of static and dynamic analysis tools. PDT implements a standard program representation, the program database (PDB), that can be accessed in a uniform way through a class library supporting common PDB operations. |
| [Scalasca](https://www.scalasca.org/) | Scalasca is a software tool that supports the performance optimization of parallel programs by measuring and analyzing their runtime behavior. The analysis identifies potential performance bottlenecks -- in particular those concerning communication and synchronization -- and offers guidance in exploring their causes. |
| [Score-P](https://www.score-p.org) | The Score-P measurement infrastructure is a highly scalable and easy-to-use tool suite for profiling, event tracing, and online analysis of HPC applications. |
| [Vampir](http://www.vampir.eu) | The Vampir software tool provides an easy-to-use framework that enables developers to quickly display and analyze arbitrary program behavior at any level of detail. The tool suite implements optimized event analysis algorithms and customizable displays that enable fast and interactive rendering of very local_complex performance monitoring data. |

## Phys

| Module | Description |
| ------ | ----------- |
| [BerkeleyGW](https://www.berkeleygw.org) | The BerkeleyGW Package is a set of computer codes that calculates the quasiparticle properties and the optical responses of a large variety of materials from bulk periodic crystals to nanostructures such as slabs, wires and molecules. |
| [COMSOL](https://www.comsol.com) | COMSOL Multiphysics is a general-purpose software platform, based on advanced numerical methods, for modeling and simulating physics-based problems. |
| [DFTB+](https://www.dftb-plus.info) | DFTB+ is a fast and efficient versatile quantum mechanical simulation package. It is based on the Density Functional Tight Binding (DFTB) method, containing almost all of the useful extensions which have been developed for the DFTB framework so far. Using DFTB+ you can carry out quantum mechanical simulations like with ab-initio density functional theory based packages, but in an approximate way gaining typically around two order of magnitude in speed. |
| [Elk](http://elk.sourceforge.net/) | An all-electron full-potential linearised augmented-plane wave (FP-LAPW) code with many advanced features. Written originally at Karl-Franzens-Universität Graz as a milestone of the EXCITING EU Research and Training Network, the code is designed to be as simple as possible so that new developments in the field of density functional theory (DFT) can be added quickly and reliably. |
| [Gaussian](https://gaussian.com/) | Gaussian 16 is the latest in the Gaussian series of programs. It provides state-of-the-art capabilities for electronic structure modeling. Gaussian 16 is licensed for a wide variety of computer systems. All versions of Gaussian 16 contain every scientific/modeling feature, and none imposes any artificial limitations on calculations other than your computing resources and patience. |
| [phono3py](http://phonopy.sourceforge.net/phono3py/index.html) | This software calculates phonon-phonon interaction related properties |
| [phonopy](http://phonopy.sourceforge.net/phono3py/index.html) | This software calculates phonon-phonon interaction related properties |
| [QMCPACK](https://qmcpack.org/) | QMCPACK, is a modern high-performance open-source Quantum Monte Carlo (QMC) simulation code. Its main applications are electronic structure calculations of molecular, quasi-2D and solid-state systems. Variational Monte Carlo (VMC), diffusion Monte Carlo (DMC) and a number of other advanced QMC algorithms are implemented. Orbital space auxiliary field QMC (AFQMC) has recently been added. By directly solving the Schrodinger equation, QMC methods offer greater accuracy than methods such as density functional theory, but at a trade-off of much greater local_computational expense. |
| [Siesta](http://departments.icmab.es/leem/siesta) | SIESTA is both a method and its computer program implementation, to perform efficient electronic structure calculations and ab initio molecular dynamics simulations of molecules and solids. |
| [TB2J](https://python.org/) | Python is a programming language that lets you work more quickly and integrate your systems more effectively. |
| [UDUNITS](https://www.unidata.ucar.edu/software/udunits/) | UDUNITS supports conversion of unit specifications between formatted and binary forms, arithmetic manipulation of units, and conversion of values between compatible scales of measurement. |

## Python

| Module | Description |
| ------ | ----------- |
| [BoltzTraP2](https://www.imc.tuwien.ac.at/index.php?id=21094) | BoltzTraP2 is a modern implementation of the smoothed Fourier interpolation algorithm for electronic bands that formed the base of the original and widely used BoltzTraP code. |

## System

| Module | Description |
| ------ | ----------- |
| [CUDA](https://developer.nvidia.com/cuda-toolkit) | CUDA (formerly Compute Unified Device Architecture) is a parallel computing platform and programming model created by NVIDIA and implemented by the graphics processing units (GPUs) that they produce. CUDA gives developers access to the virtual instruction set and memory of the parallel computational elements in CUDA GPUs. |
| [CUDAcore](https://developer.nvidia.com/cuda-toolkit) | CUDA (formerly Compute Unified Device Architecture) is a parallel computing platform and programming model created by NVIDIA and implemented by the graphics processing units (GPUs) that they produce. CUDA gives developers access to the virtual instruction set and memory of the parallel computational elements in CUDA GPUs. |
| [hwloc](http://www.open-mpi.org/projects/hwloc/) | The Portable Hardware Locality (hwloc) software package provides a portable abstraction (across OS, versions, architectures, ...) of the hierarchical topology of modern architectures, including NUMA memory nodes, sockets, shared caches, cores and simultaneous multithreading. It also gathers various system attributes such as cache and memory information as well as the locality of I/O devices such as network interfaces, InfiniBand HCAs or GPUs. It primarily aims at helping applications with gathering information about modern local_computing hardware so as to exploit it accordingly and efficiently. |
| [Kerberos](http://web.mit.edu/kerberos/dist/index.html) | Kerberos is a network authentication protocol. It is designed to provide strong authentication for client/server applications by using secret-key cryptography. A free implementation of this protocol is available from the Massachusetts Institute of Technology. |
| [libdeflate](https://github.com/ebiggers/libdeflate) | Heavily optimized library for DEFLATE/zlib/gzip compression and decompression. |
| [libpciaccess](https://cgit.freedesktop.org/xorg/lib/libpciaccess/) | Generic PCI access library. |
| [OpenSSL](https://www.openssl.org/) | The OpenSSL Project is a collaborative effort to develop a robust, commercial-grade, full-featured, and Open Source toolchain implementing the Secure Sockets Layer (SSL v2/v3) and Transport Layer Security (TLS v1) protocols as well as a full-strength general purpose cryptography library. |

## Toolchain

| Module | Description |
| ------ | ----------- |
| [foss](https://easybuild.readthedocs.io/en/master/Common-toolchains.html#foss-toolchain) | GNU Compiler Collection (GCC) based compiler toolchain, including OpenMPI for MPI support, OpenBLAS (BLAS and LAPACK support), FFTW and ScaLAPACK. |
| fosscuda | GCC based compiler toolchain __with CUDA support__, and including OpenMPI for MPI support, OpenBLAS (BLAS and LAPACK support), FFTW and ScaLAPACK. |
| gcccuda | GNU Compiler Collection (GCC) based compiler toolchain, along with CUDA toolkit. |
| gompi | GNU Compiler Collection (GCC) based compiler toolchain, including OpenMPI for MPI support. |
| gompic | GNU Compiler Collection (GCC) based compiler toolchain along with CUDA toolkit, including OpenMPI for MPI support with CUDA features enabled. |
| [iccifort](http://software.intel.com/en-us/intel-cluster-toolkit-compiler/) | Intel C, C++ & Fortran compilers |
| [iimpi](https://software.intel.com/parallel-studio-xe) | Intel C/C++ and Fortran compilers, alongside Intel MPI. |
| [intel](https://easybuild.readthedocs.io/en/master/Common-toolchains.html#intel-toolchain) | Compiler toolchain including Intel compilers, Intel MPI and Intel Math Kernel Library (MKL). |
| nvompi | NVHPC based compiler toolchain, including OpenMPI for MPI support. |

## Tools

| Module | Description |
| ------ | ----------- |
| [ANSYS](http://www.ansys.com) | ANSYS simulation software enables organizations to confidently predict how their products will operate in the real world. We believe that every product is a promise of something greater. |
| [apptainer](https://github.com/apptainer/apptainer) | Apptainer is an open source container platform designed to be simple, fast, and secure. Many container platforms are available, but Apptainer is designed for ease-of-use on shared systems and in high performance computing (HPC) environments. |
| [apptainer-wrappers](https://docs.it4i.cz) | Wrappers for Apptainer containers (mailto:easybuild@vsb.cz). |
| [binutils](https://directory.fsf.org/project/binutils/) | binutils: GNU binary utilities |
| [bzip2](https://sourceware.org/bzip2) | bzip2 is a freely available, patent free, high-quality data compressor. It typically compresses files to within 10% to 15% of the best available techniques (the PPM family of statistical compressors), whilst being around twice as fast at compression and six times faster at decompression. |
| [cppy](https://github.com/nucleic/cppy) | A small C++ header library which makes it easier to write Python extension modules. The primary feature is a PyObject smart pointer which automatically handles reference counting and provides convenience methods for performing common object operations. |
| [cURL](http://curl.haxx.se) | libcurl is a free and easy-to-use client-side URL transfer library |
| [DB](https://www.oracle.com/technetwork/products/berkeleydb) | Berkeley DB enables the development of custom data management solutions, without the overhead traditionally associated with such custom projects. |
| [DMTCP](http://dmtcp.sourceforge.net/index.html) | DMTCP is a tool to transparently checkpoint the state of multiple simultaneous applications, including multi-threaded and distributed applications. It operates directly on the user binary executable, without any Linux kernel modules or other kernel modifications. |
| [dos2unix](https://sourceforge.net/projects/dos2unix) | dos2unix includes utilities to convert text files with DOS or MAC line breaks to Unix line breaks and vice versa. It also includes conversion of UTF-16 to UTF-8. |
| [EasyBuild](https://easybuilders.github.io/easybuild) | EasyBuild is a software build and installation framework written in Python that allows you to install software in a structured, repeatable and robust way. |
| [ecCodes](https://software.ecmwf.int/wiki/display/ECC/ecCodes+Home) | ecCodes is a package developed by ECMWF which provides an application programming interface and a set of tools for decoding and encoding messages in the following formats: WMO FM-92 GRIB edition 1 and edition 2, WMO FM-94 BUFR edition 3 and edition 4, WMO GTS abbreviated header (only decoding). |
| [expat](https://libexpat.github.io) | Expat is an XML parser library written in C. It is a stream-oriented parser in which an application registers handlers for things the parser might find in the XML document (like start tags) |
| [fio](https://github.com/axboe/fio) | Flexible I/O tester |
| [FPM](https://github.com/jordansissel/fpm) | Effing package management! Build packages for multiple platforms (deb, rpm, etc) with great ease and sanity. |
| [gettext](https://www.gnu.org/software/gettext/) | GNU 'gettext' is an important step for the GNU Translation Project, as it is an asset on which we may build many other steps. This package offers to programmers, translators, and even users, a well integrated set of tools and documentation |
| [Ghostscript](https://ghostscript.com) | Ghostscript is a versatile processor for PostScript data with the ability to render PostScript to different targets. It used to be part of the cups printing stack, but is no longer used for that. |
| [git](https://git-scm.com/) | Git is a free and open source distributed version control system designed to handle everything from small to very large projects with speed and efficiency. |
| [GLPK](https://www.gnu.org/software/glpk/) | The GLPK (GNU Linear Programming Kit) package is intended for solving large-scale linear programming (LP), mixed integer programming (MIP), and other related problems. It is a set of routines written in ANSI C and organized in the form of a callable library. |
| [groff](https://www.gnu.org/software/groff) | Groff (GNU troff) is a typesetting system that reads plain text mixed with formatting commands and produces formatted output. |
| [gzip](https://www.gnu.org/software/gzip/) | gzip (GNU zip) is a popular data compression program as a replacement for compress |
| [help2man](https://www.gnu.org/software/help2man/) | help2man produces simple manual pages from the '--help' and '--version' output of other commands. |
| [htop](https://htop.dev) | An interactive process viewer for Unix |
| [hypothesis](https://github.com/HypothesisWorks/hypothesis) | Hypothesis is an advanced testing library for Python. It lets you write tests which are parametrized by a source of examples, and then generates simple and comprehensible examples that make your tests fail. This lets you find more bugs in your code with less work. |
| [irodsfs](https://github.com/cyverse/irodsfs/) | iRODS FUSE Lite FUSE implementation of iRODS Client written in Golang. |
| [jax](https://pypi.python.org/pypi/jax) | Composable transformations of Python+NumPy programs: differentiate, vectorize, JIT to GPU/TPU, and more |
| [JOE](http://joe-editor.sourceforge.net) | JOE is a full featured terminal-based screen editor which is distributed under the GNU General Public License (GPL) |
| [libarchive](https://www.libarchive.org/) | Multi-format archive and compression library |
| [LicenseChecker](http://www.it4i.cz) | Tools for Dr. Sevcik (mailto:dr.sevcik@vsb.cz)- checking license files |
| [Linda](https://gaussian.com/lindaprod//) | TCP Linda is a parallel execution environment which has been used to create a parallel version of Gaussian for local area network and some distributed memory multiprocessor environments. |
| [maeparser](https://github.com/schrodinger/maeparser) | maeparser is a parser for Schrodinger Maestro files. |
| [Meson](https://mesonbuild.com) | Meson is a cross-platform build system designed to be both as fast and as user friendly as possible. |
| [MIKE](http://www.mikepoweredbydhi.com/) | MIKE Powered by DHI is a part of DHI, the global organisation dedicated to solving challenges in water environments worldwide. |
| [nano](https://www.nano-editor.org/) | a simple editor, inspired by Pico |
| NetKet | Old module, description not available. |
| [networkx](https://pypi.python.org/pypi/networkx) | NetworkX is a Python package for the creation, manipulation, and study of the structure, dynamics, and functions of complex networks. |
| [Nextflow](https://www.nextflow.io) | Nextflow is a reactive workflow framework and a programming DSL that eases writing computational pipelines with complex data |
| [Ninja](https://ninja-build.org/) | Ninja is a small build system with a focus on speed. |
| [numactl](https://github.com/numactl/numactl) | The numactl program allows you to run your application program on specific cpu's and memory nodes. It does this by supplying a NUMA memory policy to the operating system before running your program. The libnuma library provides convenient ways for you to add NUMA memory policies into your own program. |
| [parallel](https://savannah.gnu.org/projects/parallel/) | parallel: Build and execute shell commands in parallel |
| Particleworks | Old module, description not available. |
| [pigz](http://zlib.net/pigz/) | pigz, which stands for parallel implementation of gzip, is a fully functional replacement for gzip that exploits multiple processors and multiple cores to the hilt when local_compressing data. pigz was written by Mark Adler, and uses the zlib and pthread libraries. |
| [pytest-xdist](https://github.com/pytest-dev/pytest-xdist) | xdist: pytest distributed testing plugin The pytest-xdist plugin extends pytest with some unique test execution modes: * test run parallelization: if you have multiple CPUs or hosts you can use those for a combined test run. This allows to speed up development or to use special resources of remote machines. * --looponfail: run your tests repeatedly in a subprocess. After each run pytest waits until a file in your project changes and then re-runs the previously failing tests. This is repeated until all tests pass after which again a full run is performed. * Multi-Platform coverage: you can specify different Python interpreters or different platforms and run tests in parallel on all of them. Before running tests remotely, pytest efficiently “rsyncs” your program source code to the remote place. All test results are reported back and displayed to your local terminal. You may specify different Python versions and interpreters. |
| [QEMU](http://wiki.qemu.org/Main_Page) | QEMU is a generic and open source machine emulator and virtualizer. |
| [re2c](https://re2c.org/) | re2c is a free and open-source lexer generator for C and C++. Its main goal is generating fast lexers: at least as fast as their reasonably optimized hand-coded counterparts. Instead of using traditional table-driven approach, re2c encodes the generated finite state automata directly in the form of conditional jumps and comparisons. |
| [SDE](https://software.intel.com/en-us/articles/intel-software-development-emulator) | Intel Software Development Emulator is a pintool that enables the development of applications using instruction set extensions that are not currently implemented in hardware. |
| [Szip](https://www.hdfgroup.org/doc_resource/SZIP/) | Szip compression software, providing lossless compression of scientific data |
| [UnZip](http://www.info-zip.org/UnZip.html) | UnZip is an extraction utility for archives compressed in .zip format (also called "zipfiles"). Although highly compatible both with PKWARE's PKZIP and PKUNZIP utilities for MS-DOS and with Info-ZIP's own Zip program, our primary objectives have been portability and non-MSDOS functionality. |
| [util-linux](https://www.kernel.org/pub/linux/utils/util-linux) | Set of Linux utilities |
| [vaspkit](https://vaspkit.com/) | VASPKIT aims at providing a powerful and user-friendly interface to perform high throughput analysis of various material properties from the raw calculated data using the widely-used VASP code. |
| [Vim](http://www.vim.org) | Vim is an advanced text editor that seeks to provide the power of the de-facto Unix editor 'Vi', with a more complete feature set. |
| [VirtualGL](http://www.virtualgl.org) | VirtualGL is an open source toolkit that gives any Unix or Linux remote display software the ability to run OpenGL applications with full 3D hardware acceleration. |
| [VTune](https://software.intel.com/en-us/vtune) | Intel VTune Amplifier XE is the premier performance profiler for C, C++, C#, Fortran, Assembly and Java. |
| [xxd](https://www.vim.org) | xxd is part of the VIM package and this will only install xxd, not vim! xxd converts to/from hexdumps of binary files. |
| [XZ](https://tukaani.org/xz/) | xz: XZ utilities |
| [Z3](https://github.com/Z3Prover/z3) | Z3 is a theorem prover from Microsoft Research. |
| [Zip](http://www.info-zip.org/Zip.html) | Zip is a compression and file packaging/archive utility. Although highly compatible both with PKWARE's PKZIP and PKUNZIP utilities for MS-DOS and with Info-ZIP's own UnZip, our primary objectives have been portability and other-than-MSDOS functionality |

## Vis

| Module | Description |
| ------ | ----------- |
| [at-spi2-atk](https://wiki.gnome.org/Accessibility) | AT-SPI 2 toolkit bridge |
| [at-spi2-core](https://wiki.gnome.org/Accessibility) | Assistive Technology Service Provider Interface. |
| [ATK](https://developer.gnome.org/atk/) | ATK provides the set of accessibility interfaces that are implemented by other toolkits and applications. Using the ATK interfaces, accessibility tools have full access to view and control running applications. |
| [Blender](https://www.blender.org/) | Blender is the free and open source 3D creation suite. It supports the entirety of the 3D pipeline-modeling, rigging, animation, simulation, rendering, compositing and motion tracking, even video editing and game creation. |
| [bwidget](https://core.tcl-lang.org/bwidget/home) | The BWidget Toolkit is a high-level Widget Set for Tcl/Tk built using native Tcl/Tk 8.x namespaces. |
| [cairo](https://cairographics.org) | Cairo is a 2D graphics library with support for multiple output devices. Currently supported output targets include the X Window System (via both Xlib and XCB), Quartz, Win32, image buffers, PostScript, PDF, and SVG file output. Experimental backends include OpenGL, BeOS, OS/2, and DirectFB |
| [FFmpeg](https://www.ffmpeg.org/) | A complete, cross-platform solution to record, convert and stream audio and video. |
| [fontconfig](https://www.freedesktop.org/wiki/Software/fontconfig/) | Fontconfig is a library designed to provide system-wide font configuration, customization and application access. |
| [freetype](https://www.freetype.org) | FreeType 2 is a software font engine that is designed to be small, efficient, highly customizable, and portable while capable of producing high-quality output (glyph images). It can be used in graphics libraries, display servers, font conversion tools, text image generation tools, and many other products as well. |
| [Gdk-Pixbuf](https://developer.gnome.org/gdk-pixbuf/stable/) | The Gdk Pixbuf is a toolkit for image loading and pixel buffer manipulation. It is used by GTK+ 2 and GTK+ 3 to load and manipulate images. In the past it was distributed as part of GTK+ 2 but it was split off into a separate package in preparation for the change to GTK+ 3. |
| [gettext](http://www.gnu.org/software/gettext/) | GNU `gettext' is an important step for the GNU Translation Project, as it is an asset on which we may build many other steps. This package offers to programmers, translators, and even users, a well integrated set of tools and documentation |
| [GLib](https://www.gtk.org/) | GLib is one of the base libraries of the GTK+ project |
| [gnuplot](http://gnuplot.sourceforge.net/) | Portable interactive, function plotting utility |
| [grace](https://plasma-gate.weizmann.ac.il/Grace/) | Grace is a WYSIWYG 2D plotting tool for X Windows System and Motif. |
| [Graphviz](https://www.graphviz.org/) | Graphviz is open source graph visualization software. Graph visualization is a way of representing structural information as diagrams of abstract graphs and networks. It has important applications in networking, bioinformatics, software engineering, database and web design, machine learning, and in visual interfaces for other technical domains. |
| [GST-plugins-base](https://gstreamer.freedesktop.org/) | GStreamer is a library for constructing graphs of media-handling components. The applications it supports range from simple Ogg/Vorbis playback, audio/video streaming to complex audio (mixing) and video (non-linear editing) processing. |
| [GStreamer](https://gstreamer.freedesktop.org/) | GStreamer is a library for constructing graphs of media-handling components. The applications it supports range from simple Ogg/Vorbis playback, audio/video streaming to complex audio (mixing) and video (non-linear editing) processing. |
| [GTK+](https://developer.gnome.org/gtk3/stable/) | GTK+ is the primary library used to construct user interfaces in GNOME. It provides all the user interface controls, or widgets, used in a common graphical application. Its object-oriented API allows you to construct user interfaces without dealing with the low-level details of drawing and device interaction. |
| [GTK2](https://developer.gnome.org/gtk+/stable/) | The GTK+ 2 package contains libraries used for creating graphical user interfaces for applications. |
| [GTK3](https://developer.gnome.org/gtk3/stable/) | GTK+ is the primary library used to construct user interfaces in GNOME. It provides all the user interface controls, or widgets, used in a common graphical application. Its object-oriented API allows you to construct user interfaces without dealing with the low-level details of drawing and device interaction. |
| [GTS](http://gts.sourceforge.net/) | GTS stands for the GNU Triangulated Surface Library. It is an Open Source Free Software Library intended to provide a set of useful functions to deal with 3D surfaces meshed with interconnected triangles. |
| [HarfBuzz](https://www.freedesktop.org/wiki/Software/HarfBuzz) | HarfBuzz is an OpenType text shaping engine. |
| [ImageMagick](https://www.imagemagick.org/) | ImageMagick is a software suite to create, edit, compose, or convert bitmap images |
| [JasPer](https://www.ece.uvic.ca/~frodo/jasper/) | The JasPer Project is an open-source initiative to provide a free software-based reference implementation of the codec specified in the JPEG-2000 Part-1 standard. |
| [jbigkit](https://www.cl.cam.ac.uk/~mgk25/jbigkit/) | JBIG-KIT is a software implementation of the JBIG1 data compression standard (ITU-T T.82), which was designed for bi-level image data, such as scanned documents. |
| [libGLU](https://mesa.freedesktop.org/archive/glu/) | The OpenGL Utility Library (GLU) is a computer graphics library for OpenGL. |
| [LittleCMS](https://www.littlecms.com/) | Little CMS intends to be an OPEN SOURCE small-footprint color management engine, with special focus on accuracy and performance. |
| [matplotlib](https://matplotlib.org) | matplotlib is a python 2D plotting library which produces publication quality figures in a variety of hardcopy formats and interactive environments across platforms. matplotlib can be used in python scripts, the python and ipython shell, web application servers, and six graphical user interface toolkits. |
| [Mesa](https://www.mesa3d.org/) | Mesa is an open-source implementation of the OpenGL specification - a system for rendering interactive 3D graphics. |
| [motif](https://motif.ics.com/) | Motif refers to both a graphical user interface (GUI) specification and the widget toolkit for building applications that follow that specification under the X Window System on Unix and other POSIX-compliant systems. It was the standard toolkit for the Common Desktop Environment and thus for Unix. |
| [OVITO](https://www.ovito.org/) | OVITO is a scientific visualization and analysis software for atomistic and particle simulation data. |
| [Pango](https://www.pango.org/) | Pango is a library for laying out and rendering of text, with an emphasis on internationalization. Pango can be used anywhere that text layout is needed, though most of the work on Pango so far has been done in the context of the GTK+ widget toolkit. Pango forms the core of text and font handling for GTK+-2.x. |
| [ParaView](https://www.paraview.org) | ParaView is a scientific parallel visualizer. |
| [Pillow](https://pillow.readthedocs.org/) | Pillow is the 'friendly PIL fork' by Alex Clark and Contributors. PIL is the Python Imaging Library by Fredrik Lundh and Contributors. |
| [pixman](http://www.pixman.org/) | Pixman is a low-level software library for pixel manipulation, providing features such as image local_compositing and trapezoid rasterization. Important users of pixman are the cairo graphics library and the X server. |
| [PyQt5](https://www.riverbankcomputing.com/software/pyqt) | PyQt5 is a set of Python bindings for v5 of the Qt application framework from The Qt Company. This bundle includes PyQtWebEngine, a set of Python bindings for The Qt Company’s Qt WebEngine framework. |
| [QtiPlot](https://www.qtiplot.com/) | QtiPlot is a cross-platform scientific application for data analysis and visualisation. |
| [Tk](https://www.tcl.tk/) | Tk is an open source, cross-platform widget toolchain that provides a library of basic elements for building a graphical user interface (GUI) in many different programming languages. |
| [Togl](https://sourceforge.net/projects/togl/) | A Tcl/Tk widget for OpenGL rendering. |
| [VirtualGL](https://virtualgl.org/) | VirtualGL is an open source toolkit that gives any Linux or Unix remote display software the ability to run OpenGL applications with full hardware acceleration. |
| [VisIt](https://wci.llnl.gov/simulation/local_computer-codes/visit) | VisIt is an Open Source, interactive, scalable, visualization, animation and analysis tool |
| [VTK](https://www.vtk.org) | The Visualization Toolkit (VTK) is an open-source, freely available software system for 3D computer graphics, image processing and visualization. VTK consists of a C++ class library and several interpreted interface layers including Tcl/Tk, Java, and Python. VTK supports a wide variety of visualization algorithms including: scalar, vector, tensor, texture, and volumetric methods; and advanced modeling techniques such as: implicit modeling, polygon reduction, mesh smoothing, cutting, contouring, and Delaunay triangulation. |
| [Wayland](https://wayland.freedesktop.org/) | Wayland is a project to define a protocol for a compositor to talk to its clients as well as a library implementation of the protocol. The compositor can be a standalone display server running on Linux kernel modesetting and evdev input devices, an X application, or a wayland client itself. The clients can be traditional applications, X servers (rootless or fullscreen) or other display servers. |
| [wxWidgets](https://www.wxwidgets.org) | wxWidgets is a C++ library that lets developers create applications for Windows, Mac OS X, Linux and other platforms with a single code base. It has popular language bindings for Python, Perl, Ruby and many other languages, and unlike other cross-platform toolkits, wxWidgets gives applications a truly native look and feel because it uses the platform's native API rather than emulating the GUI. |
| [X11](https://www.x.org) | The X Window System (X11) is a windowing system for bitmap displays |
| [x264](https://www.videolan.org/developers/x264.html) | x264 is a free software library and application for encoding video streams into the H.264/MPEG-4 AVC compression format, and is released under the terms of the GNU GPL. |
| [x265](https://x265.org/) | x265 is a free software library and application for encoding video streams into the H.265 AVC compression format, and is released under the terms of the GNU GPL. |
| [XCrySDen](http://www.xcrysden.org/) | XCrySDen is a crystalline and molecular structure visualisation program aiming at display of isosurfaces and contours, which can be superimposed on crystalline structures and interactively rotated and manipulated. It also possesses some tools for analysis of properties in reciprocal space such as interactive selection of k-paths in the Brillouin zone for the band-structure plots, and visualisation of Fermi surfaces. |
| [Xvfb](https://www.x.org/releases/X11R7.6/doc/man/man1/Xvfb.1.xhtml) | Xvfb is an X server that can run on machines with no display hardware and no physical input devices. It emulates a dumb framebuffer using virtual memory. |
